AtlasGeometry

Struct AtlasGeometry 

#[non_exhaustive]
pub struct AtlasGeometry { pub cell_w: u32, pub cell_h: u32, pub layers: u32, }
The packing of glyph cells into an array texture: a fixed ATLAS_COLSxATLAS_ROWS grid of cell_wxcell_h glyph cells per layer, across layers layers.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
cell_w: u32

Glyph cell width in texels (one unscaled font pixel per texel).

cell_h: u32

Glyph cell height in texels.

layers: u32

Number of array layers.

Implementations

Source

impl AtlasGeometry

pub const fn new(cell_w: u32, cell_h: u32, capacity: u32) -> Self

Geometry with enough layers to hold capacity glyph slots (at least one layer).

pub const fn tex_w(&self) -> u32

One layer’s texture width in texels.

pub const fn tex_h(&self) -> u32

One layer’s texture height in texels.

pub const fn locate(slot: u32) -> (u32, u32, u32)

Maps a flat slot index to its (layer, glyph_column, glyph_row).